aerosoltools.aerosol2d.Aerosol2D.convert_to_volume_concentration — aerosoltools 0.1.0 documentation

# aerosoltools.aerosol2d.Aerosol2D.convert_to_volume_concentration

Aerosol2D.convert_to_volume_concentration(inplace=True)

  Convert particle size distribution data to volume concentration (nm³/cm³) based on the current data type.

  ## Parameters

  inplacebool, optional

    If True (default), modifies the current instance in-place. If False, returns a new instance with volume concentration data.

  ## Returns

  self or aerosolxd

    Updated instance with volume concentration data, either in-place or as a copy.

  Parameters:

    inplace (bool)